"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const { resolvePath } = require('babel-plugin-module-resolver');
class AliasResolver {
    constructor(root, aliases = {}) {
        this.aliases = {};
        this.rule = /(?:require|import)[^'"]*(?:'|")([^'"]*)(?:'|")/gi;
        this.parseLine = (line, filePath) => {
            const transformedLine = line.replace(this.rule, (substr, moduleId) => {
                let relativeModule = resolvePath(moduleId, filePath, { root: this.root, alias: this.aliases });
                if (!relativeModule) {
                    return substr;
                }
                relativeModule = relativeModule.replace('../', '');
                return substr.replace(moduleId, relativeModule);
            });
            return transformedLine;
        };
        this.root = root;
        this.aliases = aliases;
    }
    static create(root, aliases = {}) {
        return new AliasResolver(root, aliases);
    }
    resolve(filePath, content) {
        let lines = content.split('\n');
        lines = lines.map((line) => this.parseLine(line, filePath));
        return lines.join('\n');
    }
}
exports.AliasResolver = AliasResolver;
//# sourceMappingURL=alias-resolver.js.map